# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/shopping/status/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/shopping/status/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Shopping\\Status\\": "packages/shopping/status/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Shopping\Status\Providers\StatusServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Status'  => Shopping\Status\Facades\Status::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Shopping\\StatusTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Shopping\Status\Providers\StatusServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Shopping\Status\Providers\StatusServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Shopping\Status\Providers\StatusServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/status/{modulename}

**User**

    http://path-to-route-folder/user/status/{modulename}

**Public**

    http://path-to-route-folder/statuses


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/status/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/status/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/status/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/status/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/status/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/status/{modulename}/{slug}
    METHOD: GET