<?php

namespace Shopping\Status\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Shopping\Status\Http\Requests\StatusRequest;
use Shopping\Status\Interfaces\StatusRepositoryInterface;
use Shopping\Status\Models\Status;
use Shopping\Status\Forms\Status as Form;

/**
 * APIController  class for status.
 */
class StatusAPIController extends BaseController
{

    /**
     * Initialize status resource controller.
     *
     * @param type StatusRepositoryInterface $status
     *
     * @return null
     */
    public function __construct(StatusRepositoryInterface $status)
    {
        parent::__construct();
        $this->repository = $status;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Shopping\Status\Repositories\Criteria\StatusResourceCriteria::class);
    }

    /**
     * Display a list of status.
     *
     * @return Response
     */
    public function index(StatusRequest $request)
    {
        return $this->repository
            ->setPresenter(\Shopping\Status\Repositories\Presenter\StatusPresenter::class)
            ->paginate();
    }

    /**
     * Display status.
     *
     * @param Request $request
     * @param Model   $status
     *
     * @return Response
     */
    public function show(StatusRequest $request, Status $status)
    {
        return $status->setPresenter(\Shopping\Status\Repositories\Presenter\StatusListPresenter::class);
        ;
    }

    /**
     * Create new status.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(StatusRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('status::status.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('status/status/' . $status->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('status/status');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the status.
     *
     * @param Request $request
     * @param Model   $status
     *
     * @return Response
     */
    public function update(StatusRequest $request, Status $status)
    {
        try {
            $data = $request->all();

            $status->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('status::status.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('status/status/' . $status->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('status/status/' . $status->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the status.
     *
     * @param Model   $status
     *
     * @return Response
     */
    public function destroy(StatusRequest $request, Status $status)
    {
        try {
            $status->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('status::status.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('status/status/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('status/status/' . $status->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
